Function install

pub fn install()
Install a panic handler that will restore the terminal on panic

This should be called at the start of your program, before entering the TUI.

Example

use hojicha::panic_handler;

fn main() {
    panic_handler::install();
    // ... run your TUI application
}