MouseEvent

Struct MouseEvent 

pub struct MouseEvent {
    pub kind: MouseEventKind,
    pub column: u16,
    pub row: u16,
    pub modifiers: KeyModifiers,
}
A mouse event

Example

match event {
    Event::Mouse(mouse) => {
        if mouse.is_left_click() {
            println!("Left clicked at ({}, {})", mouse.column, mouse.row);
        } else if mouse.is_scroll_up() {
            println!("Scrolled up");
        }
    }
    _ => {}
}

Fields

kind: MouseEventKind

The kind of mouse event

column: u16

Column (x coordinate)

row: u16

Row (y coordinate)

modifiers: KeyModifiers

Key modifiers held during the event

Implementations

Source

impl MouseEvent

pub fn new( kind: MouseEventKind, column: u16, row: u16, modifiers: KeyModifiers, ) -> MouseEvent

Create a new mouse event

pub fn is_left_click(&self) -> bool

Check if this is a left button click (button down event)

pub fn is_right_click(&self) -> bool

Check if this is a right button click (button down event)

pub fn is_middle_click(&self) -> bool

Check if this is a middle button click (button down event)

pub fn is_click(&self) -> bool

Check if this is any button click (button down event)

pub fn is_release(&self) -> bool

Check if this is a button release event

pub fn is_drag(&self) -> bool

Check if this is a drag event (mouse moved while button pressed)

pub fn is_left_drag(&self) -> bool

Check if this is a left button drag

pub fn is_right_drag(&self) -> bool

Check if this is a right button drag

pub fn is_middle_drag(&self) -> bool

Check if this is a middle button drag

pub fn is_scroll_up(&self) -> bool

Check if this is a scroll up event

pub fn is_scroll_down(&self) -> bool

Check if this is a scroll down event

pub fn is_scroll_left(&self) -> bool

Check if this is a scroll left event

pub fn is_scroll_right(&self) -> bool

Check if this is a scroll right event

pub fn is_scroll(&self) -> bool

Check if this is any scroll event

pub fn is_move(&self) -> bool

Check if this is a mouse move event (without button pressed)

pub fn button(&self) -> Option<MouseButton>

Get the button involved in this event, if any

pub fn position(&self) -> (u16, u16)

Get the position as a tuple (column, row)

pub fn is_within(&self, x: u16, y: u16, width: u16, height: u16) -> bool

Check if the mouse event occurred within a rectangular area

Example
let (x, y, width, height) = (10, 10, 20, 10);
if mouse_event.is_within(x, y, width, height) {
    // Mouse event is within the rectangle
}
pub fn is_at(&self, column: u16, row: u16) -> bool

Check if the mouse event occurred at a specific position

pub fn has_modifier(&self, modifier: KeyModifiers) -> bool

Check if a modifier key was held during the event

pub fn is_ctrl(&self) -> bool

Check if control key is held

pub fn is_alt(&self) -> bool

Check if alt key is held

pub fn is_shift(&self) -> bool

Check if shift key is held

pub fn has_modifiers(&self) -> bool

Check if this mouse event has any modifiers

pub fn no_modifiers(&self) -> bool

Check if this mouse event has no modifiers